
C H. K. D. H. Bhadeshia, Diffusivity of carbon in austenite
C Department of Materials Science and Metallurgy
C Charles Babbage Street, Cambridge CB3 0FS, U. K.
C 11 December 2022

C Based on "Diffusion of carbon in austenite", H. K. D. H. Bhadeshia,
C Metal Science 15 (1981) 477-478
C download publication:
C www.phase-trans.msm.cam.ac.uk/2002/carbon.diffusion.bhadeshia.metal.science.1981.pdf
C
C
C Program for the calculation of the diffusivity of carbon in austenite
C as a function of carbon concentration and temperature. Also accounts for
C the infulence of C, Mn, Si, Ni, Mo, Cr and V on the activity of carbon
C in austenite, and therefore on the diffusivity of carbon.
C
C Typical data
C 0.04 0.20 0.30 0.40 0.30 0.40 0.40
C C SI MN NI MO CR V (wt.%)
C 700 CENTIGRADE
C
           IMPLICIT REAL*8(A-H,O-Z), INTEGER(I-N)
           DOUBLE PRECISION C(8)
           WRITE(*,*)'        Temperature, Centigrade ?'
           READ(*,*)CTEMP
      WRITE(*,*)'        Carbon concentration, wt.% ?'
      READ(*,*)C(1)
      WRITE(*,*)'        Silicon concentration, wt.% ?'
      READ(*,*)C(2)
      WRITE(*,*)'        Manganese concentration, wt.% ?'
      READ(*,*)C(3)
      WRITE(*,*)'        Nickel concentration, wt.% ?'
      READ(*,*)C(4)
      WRITE(*,*)'        Molybdenum concentration, wt.% ?'
      READ(*,*)C(5)
      WRITE(*,*)'        Chromium concentration, wt.% ?'
      READ(*,*)C(6)
      WRITE(*,*)'        Vanadium concentration, wt.% ?'
      READ(*,*)C(7)
           CALL OMEGA(W,XBAR,C)
      CALL DIFF(DIF,C(1),CTEMP,W)
      WRITE(*,1)DIF,CTEMP
1     FORMAT(' DIFFUSION COEFFICIENT, CM**2/S, =',D12.4/
     &' TEMPERATURE, CENTIGRADE =', F8.0)
      STOP
      END

      SUBROUTINE DIFF(DIF,X,CTEMP,W)
      IMPLICIT REAL*8(A-H,O-Y), INTEGER(I-N,Z)
      HH=6.6262D-34
      BOLTZ=1.38062D-23
      Z=12
      A5=1.0D+00
      R=8.31432D+00
C     D=DIFFUSIVITY OF CARBON IN AUSTENITE
C     Z=COORDINATION OF INTERSTIAL SITE
C     PSI=COMPOSITION DEPENDENCE OF DIFFUSION COEFFICIENT
C     THETA=NO. C ATOMS/ NO. FE ATOMS
C     ACTIV=ACTIVITY OF CARBON IN AUSTENITE
C     R=GAS CONSTANT
C     X=MOLE FRACTION OF CARBON
C     T=ABSOLUTE TEMPERATURE
C     SIGMA=SITE EXCLUSION PROBABLITY
C     W=CARBON CARBON INTERACTION ENERGY IN AUSTENITE
      T=CTEMP+273.00D+00
      DASH=(BOLTZ*T/HH)*DEXP(-(21230.0D+00/T))*DEXP(-31.84D+00)
      THETA=X/(A5-X)
      ACTIV=CG(X,T,W,R)
      write(*,*) activ
      ACTIV=DEXP(ACTIV)
      write(*,*) activ
      DACTIV=DCG(X,T,W,R)
      DACTIV=DACTIV*ACTIV
      DACTIV=DACTIV*A5/((A5+THETA)**2)
      SIGMA=A5-DEXP((-(W))/(R*T))
      PSI=ACTIV*(A5+Z*((A5+THETA)/(A5-(A5+Z/2)*THETA+(Z/2)*(A5+Z/2)*
     &(A5-SIGMA)*THETA*THETA)))+(A5+THETA)*DACTIV
      DIF=DASH*PSI

      RETURN
      END
C*******************************************************************************
C FUNCTION GIVING LFG  LN(ACTIVITY) OF CARBON IN AUSTENITE
      DOUBLE PRECISION FUNCTION CG(X,T,W,R)
      DOUBLE PRECISION J,DG,DUMMY,T,R,W,X
      J=1-DEXP(-W/(R*T))
      DG=DSQRT(1-2*(1+2*J)*X+(1+8*J)*X*X)
      DUMMY=5*DLOG((1-2*X)/X)+6*W/(R*T)+((38575.0)-(
     &13.48)*T)/(R*T)
      CG=DUMMY+DLOG(((DG-1+3*X)/(DG+1-3*X))**6)
      RETURN
      END
C*******************************************************************************
C FUNCTION GIVING DIFFERENTIAL OF LN(ACTIVITY) OF CARBON IN AUSTENITE, LFG
C DIFFERENTIAL IS WITH RESPECT TO X
      DOUBLE PRECISION FUNCTION DCG(X,T,W,R)
      DOUBLE PRECISION J,DG,DDG,X,T,W,R
      J=1-DEXP(-W/(R*T))
      DG=DSQRT(1-2*(1+2*J)*X+(1+8*J)*X*X)
      DDG=(0.5/DG)*(-2-4*J+2*X+16*J*X)
      DCG=-((10/(1-2*X))+(5/X))+6*((DDG+3)/(DG-1+3*X
     &)-(DDG-3)/(DG+1-3*X))
      RETURN
      END
C*******************************************************************************
      SUBROUTINE OMEGA(W,XBAR,C)
C SUBROUTINE TO CALCULATE THE CARBON CARBON INTERACTION ENERGY IN
C AUSTENITE, AS A FUNCTION OF ALLOY COMPOSITION.  BASED ON .MUCG18
C THE ANSWER IS IN JOULES PER MOL.   **7 OCTOBER 1981**
      DOUBLE PRECISION C(8),W,P(8),B1,B2,Y(8),T10,T20,B3,XBAR
      INTEGER B5,I,U,B4
      WRITE(*,261) (C(B4),B4=1,7)
      B3=0.0D+00
      C(8)=C(1)+C(2)+C(3)+C(4)+C(5)+C(6)+C(7)
      C(8)=100.0D+00-C(8)
      C(8)=C(8)/55.84D+00
      C(1)=C(1)/12.0115D+00
      C(2)=C(2)/28.09D+00
      C(3)=C(3)/54.94D+00
      C(4)=C(4)/58.71D+00
      C(5)=C(5)/95.94D+00
      C(6)=C(6)/52.0D+00
      C(7)=C(7)/50.94D+00
      B1=C(1)+C(2)+C(3)+C(4)+C(5)+C(6)+C(7)+C(8)
      DO 107 U=2,7
      Y(U)=C(U)/C(8)
107   CONTINUE
      DO 106 U=1,8
      C(U)=C(U)/B1
106   CONTINUE
      XBAR=C(1)
      XBAR=DINT(10000.0D+00*XBAR)
      XBAR=XBAR/10000
      B2=0.0D+00
      T10=Y(2)*(-3)+Y(3)*2+Y(4)*12+Y(5)*(-9)+Y(6)*(-1)+Y(7)*(-12)
      T20=-3*Y(2)-37.5*Y(3)-6*Y(4)-26*Y(5)-19*Y(6)-44*Y(7)
      P(2)=2013.0341+763.8167*C(2)+45802.87*C(2)**2-280061.63*C(2)**3
     &+3.864D+06*C(2)**4-2.4233D+07*C(2)**5+6.9547D+07*C(2)**6
      P(3)=2012.067-1764.095*C(3)+6287.52*C(3)**2-21647.96*C(3)**3-
     &2.0119D+06*C(3)**4+3.1716D+07*C(3)**5-1.3885D+08*C(3)**6
      P(4)=2006.8017+2330.2424*C(4)-54915.32*C(4)**2+1.6216D+06*C(4)**3
     &-2.4968D+07*C(4)**4+1.8838D+08*C(4)**5-5.5531D+08*C(4)**6
      P(5)=2006.834-2997.314*C(5)-37906.61*C(5)**2+1.0328D+06*C(5)**3
     &-1.3306D+07*C(5)**4+8.411D+07*C(5)**5-2.0826D+08*C(5)**6
      P(6)=2012.367-9224.2655*C(6)+33657.8*C(6)**2-566827.83*C(6)**3
     &+8.5676D+06*C(6)**4-6.7482D+07*C(6)**5 +2.0837D+08*C(6)**6
      P(7)=2011.9996-6247.9118*C(7)+5411.7566*C(7)**2
     &+250118.1085*C(7)**3-4.1676D+06*C(7)**4
      DO 108 U=2,7
      B3=B3+P(U)*Y(U)
      B2=B2+Y(U)
108   CONTINUE
      IF (B2 .EQ. 0.0D+00) GOTO 455
      W=(B3/B2)*4.187
      GOTO 456
455   W=8054.0
456   WRITE(*,261)(C(B4),B4=1,7)
      WRITE(*,1006)W
1006  FORMAT(' CARBON-CARBON INTERACTION ENERGY IN GAMMA, J/MOL=',F9.4)
261   FORMAT (6H    C=,F8.4,6H   SI=,F8.4,6H   MN=,F8.4,
     &6H   NI=,F8.4,6H   MO=,F8.4,6H   CR=,F8.4,6H    V=,F8.4)
      RETURN
      END



